# Change Log

## [0.0.2](https://github.com/dldevinc/cardpointe-api-python-client/tree/v0.0.2) - 2023-01-09

### Features

- Add Python 3.11 support (no code changes were needed, but now we test this release).

## [0.0.1](https://github.com/dldevinc/cardpointe-api-python-client/tree/v0.0.1) - 2022-10-21

-   First release
